==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebBaseDateTimeFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperandDescriptionMetadata } from "./WebFilteringOperandDescriptionMetadata";
import { WebBaseDateTimeFilteringOperandDescription } from "./WebBaseDateTimeFilteringOperandDescription";
/**
 * @hidden
 */
export let WebBaseDateTimeFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseDateTimeFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseDateTimeFilteringOperandDescriptionMetadata.a == null) {
                WebBaseDateTimeFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseDateTimeFilteringOperandDescriptionMetadata.c(WebBaseDateTimeFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebBaseDateTimeFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebBaseDateTimeFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:BaseDateTimeFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebBaseDateTimeFilteringOperandDescriptionMetadata.b(a);
            a.ad("WebBaseDateTimeFilteringOperand", () => new WebBaseDateTimeFilteringOperandDescription());
            a.ac("WebBaseDateTimeFilteringOperand", WebBaseDateTimeFilteringOperandDescriptionMetadata.a);
        }
    }
    WebBaseDateTimeFilteringOperandDescriptionMetadata.$t = markType(WebBaseDateTimeFilteringOperandDescriptionMetadata, 'WebBaseDateTimeFilteringOperandDescriptionMetadata');
    WebBaseDateTimeFilteringOperandDescriptionMetadata.a = null;
    return WebBaseDateTimeFilteringOperandDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebBaseDateTimeFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperandDescriptionMetadata } from "./WebFilteringOperandDescriptionMetadata";
import { WebBaseDateTimeFilteringOperandDescription } from "./WebBaseDateTimeFilteringOperandDescription";
/**
 * @hidden
 */
export let WebBaseDateTimeFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseDateTimeFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseDateTimeFilteringOperandDescriptionMetadata.a == null) {
                WebBaseDateTimeFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseDateTimeFilteringOperandDescriptionMetadata.c(WebBaseDateTimeFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebBaseDateTimeFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebBaseDateTimeFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:BaseDateTimeFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebBaseDateTimeFilteringOperandDescriptionMetadata.b(a);
            a.ae("WebBaseDateTimeFilteringOperand", () => new WebBaseDateTimeFilteringOperandDescription());
            a.ad("WebBaseDateTimeFilteringOperand", WebBaseDateTimeFilteringOperandDescriptionMetadata.a);
        }
    }
    WebBaseDateTimeFilteringOperandDescriptionMetadata.$t = markType(WebBaseDateTimeFilteringOperandDescriptionMetadata, 'WebBaseDateTimeFilteringOperandDescriptionMetadata');
    WebBaseDateTimeFilteringOperandDescriptionMetadata.a = null;
    return WebBaseDateTimeFilteringOperandDescriptionMetadata;
})();
